SGITHUB = 'https://raw.githubusercontent.com/saiemgilani/'
NFLVERSEGITHUB='https://raw.githubusercontent.com/nflverse/'
CFB_BASE_URL = SGITHUB+'cfbfastR-data/master/pbp/parquet/play_by_play_{season}.parquet'
CFB_ROSTER_URL = SGITHUB+'cfbfastR-data/master/rosters/parquet/rosters_{season}.parquet'
CFB_TEAM_LOGO_URL  = SGITHUB+'cfbfastR-data/master/teams/teams_colors_logos.parquet'
CFB_TEAM_SCHEDULE_URL = SGITHUB+'cfbfastR-data/master/schedules/parquet/schedules_{season}.parquet'
CFB_TEAM_INFO_URL = SGITHUB+'cfbfastR-data/master/team_info/parquet/team_info_{season}.parquet'

NFL_BASE_URL = NFLVERSEGITHUB+'nflfastR-data/master/data/play_by_play_{season}.parquet'
NFL_PLAYER_STATS_URL = NFLVERSEGITHUB+'nflfastR-data/master/data/player_stats.parquet'
NFL_ROSTER_URL = NFLVERSEGITHUB+'nflfastR-roster/master/data/nflfastR-roster.csv.gz'
NFL_TEAM_LOGO_URL  = NFLVERSEGITHUB+'nflfastR-data/master/teams_colors_logos.csv'

NFL_TEAM_SCHEDULE_URL = SGITHUB+'nflfastR-data/master/schedules/sched_{season}.parquet'